vim.opt.clipboard="unnamed,unnamedplus"
vim.g.mapleader = ' '

local lazypath = vim.fn.stdpath("data") .. "/lazy/lazy.nvim"
if not vim.loop.fs_stat(lazypath) then
  vim.fn.system({
    "git",
    "clone",
    "--filter=blob:none",
    "https://github.com/folke/lazy.nvim.git",
    "--branch=stable", -- latest stable release
    lazypath,
  })
end
vim.opt.rtp:prepend(lazypath)
require("lazy").setup({
  "nyoom-engineering/oxocarbon.nvim",
  {"nvim-treesitter/nvim-treesitter", build = ":TSUpdate"},
  {
    'nvim-orgmode/orgmode',
    dependencies = {
      { 'nvim-treesitter/nvim-treesitter', lazy = true },
    },
    event = 'VeryLazy',
    config = function()
      -- Load treesitter grammar for org
      require('orgmode').setup_ts_grammar()

      -- Setup treesitter
      require('nvim-treesitter.configs').setup({
        highlight = {
          enable = false,
          additional_vim_regex_highlighting = { 'org' },
        },
        ensure_installed = { 'org' },
      })

      -- Setup orgmode -- NOTE (to self) THAT I ONLY USE THIS FOR CAPTURING CODE 
      --                  AND CHANGING Todo STATES in todo.org FOR CODING
      --                  for simplicity's sake
      require('orgmode').setup({
        --org_agenda_files = '~/orgfiles/**/*',
        org_agenda_files = '~/notebook/ag/*',
        org_default_notes_file = '~/notebook/ag/todo.org',
	org_log_done = 'time',
	org_log_into_drawer = 'LOGBOOK',
	--org_todo_keywords = {'TODO(t)', 'NEXT(n)', '|', 'DONE(d)'},
	org_todo_keywords = {"TODO(t)", "PROJ(p)", "LOOP(r)", "STRT(s)", "WAIT(w)", "HOLD(h)", "IDEA(i)", "|", "DONE(d)", "KILL(k)"},
	org_capture_templates = {
	  t = {
	  description = 'todo with link',
	  template = '* TODO %?\n%i\n%a',
	  target = '~/notebook/ag/todo.org',
	  headline = 'todo',
	  },
	  T = {
	  description = 'todo no link',
	  template = '* TODO %?\n%i\n%a',
	  target = '~/notebook/ag/todo.org',
	  headline = 'todo',
	  },
	},
	mappings = { -- make as close to doom
	  --disable_all = true,
	  global = {
	    org_agenda = {'<Leader>oa'},
	    org_capture = '<Leader>x',
	  },
	  agenda = {
	    org_agenda_todo = '<Leader>mt',
	    org_agenda_schedule = '<Leader>mds',
	    org_agenda_deadline = '<Leader>mdd',
	    org_agenda_ = '<Leader>mds',

	  },
	  org = {
	    org_todo = '<Leader>mt',
	    org_priority = '<Leader>mpp',
	    --org_move_subtree_up = '<ALT-k>',
	    --org_move_subtree_down = '<ALT-j>',
	    org_schedule = '<Leader>mds',
	    org_deadline = '<Leader>mdd',
	    org_time_stamp = '<Leader>mdt',
	    org_time_stamp_inactive = '<Leader>mdT',
	  },
	},
      })
    end,
  },
  {
  'nvim-telescope/telescope.nvim', tag = '0.1.5',
-- or                              , branch = '0.1.x',
    dependencies = { 'nvim-lua/plenary.nvim' }
  },
})


--vim.opt.background = "dark" -- set this to dark or light
--vim.cmd("colorscheme oxocarbon")

--keybinds
vim.keymap.set("n", "<leader>.", vim.cmd.Ex)
vim.keymap.set("n", "<leader>ff", vim.cmd.Ex)
local builtin = require('telescope.builtin')
vim.keymap.set('n', '<leader><leader>', builtin.find_files, {})
--vim.keymap.set('n', '<leader>fg', builtin.live_grep, {})
--vim.keymap.set('n', '<leader>fb', builtin.buffers, {})
--vim.keymap.set('n', '<leader>fh', builtin.help_tags, {})
